#ifndef CSMSCONVERSATION_H
#define CSMSCONVERSATION_H

#include "SMSMessage.h"
#include <QList>
#include "Contact.h"

class CSMSConversation
{
public:
    CSMSConversation(CContact ConversationContact);
    CSMSConversation();
    ~CSMSConversation();

    CContact mConversationContact;
    QList<CSMSMessage*> mMessages;

    int InsertNewMessage(CSMSMessage *Message);
    int InsertMessage(CSMSMessage *Message);
    CContact *GetConversationContact();
    int SetConversationContact(CContact *Contact);
    CSMSMessage *GetMostRecentMessage();
    QList<CSMSMessage*> *GetMessages();

};

#endif // CSMSCONVERSATION_H
